pub struct GroupScopedSnapshot { /* private fields */ }Expand description
A group-scoped snapshot that only contains data for a single group.
Unlike MemoryStorageSnapshot which captures all data in the storage,
this snapshot only captures data relevant to a specific group. This enables
proper rollback isolation where rolling back Group A doesn’t affect Group B.
This matches the behavior of SQLite’s group-scoped snapshots where:
snapshot_group_state()only copies rows WHEREgroup_id = ?restore_group_from_snapshot()only deletes/restores rows for that group
Group-Scoped Data
The following data is captured per group:
- MLS group data (tree state, join config, etc.)
- MLS own leaf nodes for this group
- MLS proposals for this group
- MLS epoch key pairs for this group
- MDK group record
- MDK group relays
- MDK group exporter secrets
The following data is NOT captured (not group-scoped):
- MLS key packages (identity-scoped, not group-scoped)
- MLS PSKs (identity-scoped, not group-scoped)
- MLS signature keys (identity-scoped, not group-scoped)
- MLS encryption keys (identity-scoped, not group-scoped)
- Messages (handled separately via
invalidate_messages_after_epoch) - Welcomes (keyed by EventId, not group-scoped)