pub struct ValidationLimits {
pub cache_size: usize,
pub max_relays_per_group: usize,
pub max_messages_per_group: usize,
pub max_group_name_length: usize,
pub max_group_description_length: usize,
pub max_admins_per_group: usize,
pub max_relays_per_welcome: usize,
pub max_admins_per_welcome: usize,
pub max_relay_url_length: usize,
}Expand description
Configurable validation limits for memory storage.
This struct allows customization of the various limits used to prevent memory exhaustion attacks. All limits have sensible defaults that can be overridden using the builder pattern.
Example
use mdk_memory_storage::ValidationLimits;
let limits = ValidationLimits::default()
.with_cache_size(2000)
.with_max_messages_per_group(5000)
.with_max_relays_per_group(50);Fields
cache_size: usizeMaximum number of items in each LRU cache
max_relays_per_group: usizeMaximum number of relays allowed per group
max_messages_per_group: usizeMaximum number of messages stored per group
max_group_name_length: usizeMaximum length of a group name in bytes
max_group_description_length: usizeMaximum length of a group description in bytes
max_admins_per_group: usizeMaximum number of admin pubkeys per group
max_relays_per_welcome: usizeMaximum number of relays in a welcome message
max_admins_per_welcome: usizeMaximum number of admin pubkeys in a welcome message
max_relay_url_length: usizeMaximum length of a relay URL in bytes
Implementations
Sourceimpl ValidationLimits
impl ValidationLimits
Sourcepub fn with_cache_size(self, size: usize) -> Self
pub fn with_cache_size(self, size: usize) -> Self
Sourcepub fn with_max_relays_per_group(self, limit: usize) -> Self
pub fn with_max_relays_per_group(self, limit: usize) -> Self
Sourcepub fn with_max_messages_per_group(self, limit: usize) -> Self
pub fn with_max_messages_per_group(self, limit: usize) -> Self
Sourcepub fn with_max_group_name_length(self, limit: usize) -> Self
pub fn with_max_group_name_length(self, limit: usize) -> Self
Sourcepub fn with_max_group_description_length(self, limit: usize) -> Self
pub fn with_max_group_description_length(self, limit: usize) -> Self
Sourcepub fn with_max_admins_per_group(self, limit: usize) -> Self
pub fn with_max_admins_per_group(self, limit: usize) -> Self
Sourcepub fn with_max_relays_per_welcome(self, limit: usize) -> Self
pub fn with_max_relays_per_welcome(self, limit: usize) -> Self
Sourcepub fn with_max_admins_per_welcome(self, limit: usize) -> Self
pub fn with_max_admins_per_welcome(self, limit: usize) -> Self
Sourcepub fn with_max_relay_url_length(self, limit: usize) -> Self
pub fn with_max_relay_url_length(self, limit: usize) -> Self